import { ExceptionOptionType as __ExceptionOptionType } from "@aws-sdk/smithy-client";
import { CostExplorerServiceException as __BaseException } from "./CostExplorerServiceException";
export declare const AccountScope: {
  readonly LINKED: "LINKED";
  readonly PAYER: "PAYER";
};
export type AccountScope = (typeof AccountScope)[keyof typeof AccountScope];
export interface AnomalyScore {
  MaxScore: number | undefined;
  CurrentScore: number | undefined;
}
export declare const AnomalyFeedbackType: {
  readonly NO: "NO";
  readonly PLANNED_ACTIVITY: "PLANNED_ACTIVITY";
  readonly YES: "YES";
};
export type AnomalyFeedbackType =
  (typeof AnomalyFeedbackType)[keyof typeof AnomalyFeedbackType];
export interface Impact {
  MaxImpact: number | undefined;
  TotalImpact?: number;
  TotalActualSpend?: number;
  TotalExpectedSpend?: number;
  TotalImpactPercentage?: number;
}
export interface RootCause {
  Service?: string;
  Region?: string;
  LinkedAccount?: string;
  UsageType?: string;
  LinkedAccountName?: string;
}
export interface Anomaly {
  AnomalyId: string | undefined;
  AnomalyStartDate?: string;
  AnomalyEndDate?: string;
  DimensionValue?: string;
  RootCauses?: RootCause[];
  AnomalyScore: AnomalyScore | undefined;
  Impact: Impact | undefined;
  MonitorArn: string | undefined;
  Feedback?: AnomalyFeedbackType | string;
}
export interface AnomalyDateInterval {
  StartDate: string | undefined;
  EndDate?: string;
}
export declare const MonitorDimension: {
  readonly SERVICE: "SERVICE";
};
export type MonitorDimension =
  (typeof MonitorDimension)[keyof typeof MonitorDimension];
export declare const MatchOption: {
  readonly ABSENT: "ABSENT";
  readonly CASE_INSENSITIVE: "CASE_INSENSITIVE";
  readonly CASE_SENSITIVE: "CASE_SENSITIVE";
  readonly CONTAINS: "CONTAINS";
  readonly ENDS_WITH: "ENDS_WITH";
  readonly EQUALS: "EQUALS";
  readonly GREATER_THAN_OR_EQUAL: "GREATER_THAN_OR_EQUAL";
  readonly STARTS_WITH: "STARTS_WITH";
};
export type MatchOption = (typeof MatchOption)[keyof typeof MatchOption];
export interface CostCategoryValues {
  Key?: string;
  Values?: string[];
  MatchOptions?: (MatchOption | string)[];
}
export declare const Dimension: {
  readonly AGREEMENT_END_DATE_TIME_AFTER: "AGREEMENT_END_DATE_TIME_AFTER";
  readonly AGREEMENT_END_DATE_TIME_BEFORE: "AGREEMENT_END_DATE_TIME_BEFORE";
  readonly ANOMALY_TOTAL_IMPACT_ABSOLUTE: "ANOMALY_TOTAL_IMPACT_ABSOLUTE";
  readonly ANOMALY_TOTAL_IMPACT_PERCENTAGE: "ANOMALY_TOTAL_IMPACT_PERCENTAGE";
  readonly AZ: "AZ";
  readonly BILLING_ENTITY: "BILLING_ENTITY";
  readonly CACHE_ENGINE: "CACHE_ENGINE";
  readonly DATABASE_ENGINE: "DATABASE_ENGINE";
  readonly DEPLOYMENT_OPTION: "DEPLOYMENT_OPTION";
  readonly INSTANCE_TYPE: "INSTANCE_TYPE";
  readonly INSTANCE_TYPE_FAMILY: "INSTANCE_TYPE_FAMILY";
  readonly INVOICING_ENTITY: "INVOICING_ENTITY";
  readonly LEGAL_ENTITY_NAME: "LEGAL_ENTITY_NAME";
  readonly LINKED_ACCOUNT: "LINKED_ACCOUNT";
  readonly LINKED_ACCOUNT_NAME: "LINKED_ACCOUNT_NAME";
  readonly OPERATING_SYSTEM: "OPERATING_SYSTEM";
  readonly OPERATION: "OPERATION";
  readonly PAYMENT_OPTION: "PAYMENT_OPTION";
  readonly PLATFORM: "PLATFORM";
  readonly PURCHASE_TYPE: "PURCHASE_TYPE";
  readonly RECORD_TYPE: "RECORD_TYPE";
  readonly REGION: "REGION";
  readonly RESERVATION_ID: "RESERVATION_ID";
  readonly RESOURCE_ID: "RESOURCE_ID";
  readonly RIGHTSIZING_TYPE: "RIGHTSIZING_TYPE";
  readonly SAVINGS_PLANS_TYPE: "SAVINGS_PLANS_TYPE";
  readonly SAVINGS_PLAN_ARN: "SAVINGS_PLAN_ARN";
  readonly SCOPE: "SCOPE";
  readonly SERVICE: "SERVICE";
  readonly SERVICE_CODE: "SERVICE_CODE";
  readonly SUBSCRIPTION_ID: "SUBSCRIPTION_ID";
  readonly TENANCY: "TENANCY";
  readonly USAGE_TYPE: "USAGE_TYPE";
  readonly USAGE_TYPE_GROUP: "USAGE_TYPE_GROUP";
};
export type Dimension = (typeof Dimension)[keyof typeof Dimension];
export interface DimensionValues {
  Key?: Dimension | string;
  Values?: string[];
  MatchOptions?: (MatchOption | string)[];
}
export interface TagValues {
  Key?: string;
  Values?: string[];
  MatchOptions?: (MatchOption | string)[];
}
export declare const MonitorType: {
  readonly CUSTOM: "CUSTOM";
  readonly DIMENSIONAL: "DIMENSIONAL";
};
export type MonitorType = (typeof MonitorType)[keyof typeof MonitorType];
export declare const AnomalySubscriptionFrequency: {
  readonly DAILY: "DAILY";
  readonly IMMEDIATE: "IMMEDIATE";
  readonly WEEKLY: "WEEKLY";
};
export type AnomalySubscriptionFrequency =
  (typeof AnomalySubscriptionFrequency)[keyof typeof AnomalySubscriptionFrequency];
export declare const SubscriberStatus: {
  readonly CONFIRMED: "CONFIRMED";
  readonly DECLINED: "DECLINED";
};
export type SubscriberStatus =
  (typeof SubscriberStatus)[keyof typeof SubscriberStatus];
export declare const SubscriberType: {
  readonly EMAIL: "EMAIL";
  readonly SNS: "SNS";
};
export type SubscriberType =
  (typeof SubscriberType)[keyof typeof SubscriberType];
export interface Subscriber {
  Address?: string;
  Type?: SubscriberType | string;
  Status?: SubscriberStatus | string;
}
export interface ResourceTag {
  Key: string | undefined;
  Value: string | undefined;
}
export interface CreateAnomalyMonitorResponse {
  MonitorArn: string | undefined;
}
export declare class LimitExceededException extends __BaseException {
  readonly name: "LimitExceededException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<LimitExceededException, __BaseException>
  );
}
export interface CreateAnomalySubscriptionResponse {
  SubscriptionArn: string | undefined;
}
export declare class UnknownMonitorException extends __BaseException {
  readonly name: "UnknownMonitorException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<UnknownMonitorException, __BaseException>
  );
}
export declare const CostCategoryInheritedValueDimensionName: {
  readonly LINKED_ACCOUNT_NAME: "LINKED_ACCOUNT_NAME";
  readonly TAG: "TAG";
};
export type CostCategoryInheritedValueDimensionName =
  (typeof CostCategoryInheritedValueDimensionName)[keyof typeof CostCategoryInheritedValueDimensionName];
export interface CostCategoryInheritedValueDimension {
  DimensionName?: CostCategoryInheritedValueDimensionName | string;
  DimensionKey?: string;
}
export declare const CostCategoryRuleType: {
  readonly INHERITED_VALUE: "INHERITED_VALUE";
  readonly REGULAR: "REGULAR";
};
export type CostCategoryRuleType =
  (typeof CostCategoryRuleType)[keyof typeof CostCategoryRuleType];
export declare const CostCategoryRuleVersion: {
  readonly CostCategoryExpressionV1: "CostCategoryExpression.v1";
};
export type CostCategoryRuleVersion =
  (typeof CostCategoryRuleVersion)[keyof typeof CostCategoryRuleVersion];
export declare const CostCategorySplitChargeMethod: {
  readonly EVEN: "EVEN";
  readonly FIXED: "FIXED";
  readonly PROPORTIONAL: "PROPORTIONAL";
};
export type CostCategorySplitChargeMethod =
  (typeof CostCategorySplitChargeMethod)[keyof typeof CostCategorySplitChargeMethod];
export declare const CostCategorySplitChargeRuleParameterType: {
  readonly ALLOCATION_PERCENTAGES: "ALLOCATION_PERCENTAGES";
};
export type CostCategorySplitChargeRuleParameterType =
  (typeof CostCategorySplitChargeRuleParameterType)[keyof typeof CostCategorySplitChargeRuleParameterType];
export interface CostCategorySplitChargeRuleParameter {
  Type: CostCategorySplitChargeRuleParameterType | string | undefined;
  Values: string[] | undefined;
}
export interface CostCategorySplitChargeRule {
  Source: string | undefined;
  Targets: string[] | undefined;
  Method: CostCategorySplitChargeMethod | string | undefined;
  Parameters?: CostCategorySplitChargeRuleParameter[];
}
export interface CreateCostCategoryDefinitionResponse {
  CostCategoryArn?: string;
  EffectiveStart?: string;
}
export declare class ServiceQuotaExceededException extends __BaseException {
  readonly name: "ServiceQuotaExceededException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<ServiceQuotaExceededException, __BaseException>
  );
}
export interface DeleteAnomalyMonitorRequest {
  MonitorArn: string | undefined;
}
export interface DeleteAnomalyMonitorResponse {}
export interface DeleteAnomalySubscriptionRequest {
  SubscriptionArn: string | undefined;
}
export interface DeleteAnomalySubscriptionResponse {}
export declare class UnknownSubscriptionException extends __BaseException {
  readonly name: "UnknownSubscriptionException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<UnknownSubscriptionException, __BaseException>
  );
}
export interface DeleteCostCategoryDefinitionRequest {
  CostCategoryArn: string | undefined;
}
export interface DeleteCostCategoryDefinitionResponse {
  CostCategoryArn?: string;
  EffectiveEnd?: string;
}
export declare class ResourceNotFoundException extends __BaseException {
  readonly name: "ResourceNotFoundException";
  readonly $fault: "client";
  Message?: string;
  ResourceName?: string;
  constructor(
    opts: __ExceptionOptionType<ResourceNotFoundException, __BaseException>
  );
}
export interface DescribeCostCategoryDefinitionRequest {
  CostCategoryArn: string | undefined;
  EffectiveOn?: string;
}
export declare const CostCategoryStatusComponent: {
  readonly COST_EXPLORER: "COST_EXPLORER";
};
export type CostCategoryStatusComponent =
  (typeof CostCategoryStatusComponent)[keyof typeof CostCategoryStatusComponent];
export declare const CostCategoryStatus: {
  readonly APPLIED: "APPLIED";
  readonly PROCESSING: "PROCESSING";
};
export type CostCategoryStatus =
  (typeof CostCategoryStatus)[keyof typeof CostCategoryStatus];
export interface CostCategoryProcessingStatus {
  Component?: CostCategoryStatusComponent | string;
  Status?: CostCategoryStatus | string;
}
export declare const NumericOperator: {
  readonly BETWEEN: "BETWEEN";
  readonly EQUAL: "EQUAL";
  readonly GREATER_THAN: "GREATER_THAN";
  readonly GREATER_THAN_OR_EQUAL: "GREATER_THAN_OR_EQUAL";
  readonly LESS_THAN: "LESS_THAN";
  readonly LESS_THAN_OR_EQUAL: "LESS_THAN_OR_EQUAL";
};
export type NumericOperator =
  (typeof NumericOperator)[keyof typeof NumericOperator];
export interface TotalImpactFilter {
  NumericOperator: NumericOperator | string | undefined;
  StartValue: number | undefined;
  EndValue?: number;
}
export interface GetAnomaliesRequest {
  MonitorArn?: string;
  DateInterval: AnomalyDateInterval | undefined;
  Feedback?: AnomalyFeedbackType | string;
  TotalImpact?: TotalImpactFilter;
  NextPageToken?: string;
  MaxResults?: number;
}
export interface GetAnomaliesResponse {
  Anomalies: Anomaly[] | undefined;
  NextPageToken?: string;
}
export declare class InvalidNextTokenException extends __BaseException {
  readonly name: "InvalidNextTokenException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<InvalidNextTokenException, __BaseException>
  );
}
export interface GetAnomalyMonitorsRequest {
  MonitorArnList?: string[];
  NextPageToken?: string;
  MaxResults?: number;
}
export interface GetAnomalySubscriptionsRequest {
  SubscriptionArnList?: string[];
  MonitorArn?: string;
  NextPageToken?: string;
  MaxResults?: number;
}
export declare class BillExpirationException extends __BaseException {
  readonly name: "BillExpirationException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<BillExpirationException, __BaseException>
  );
}
export declare class DataUnavailableException extends __BaseException {
  readonly name: "DataUnavailableException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<DataUnavailableException, __BaseException>
  );
}
export declare const Granularity: {
  readonly DAILY: "DAILY";
  readonly HOURLY: "HOURLY";
  readonly MONTHLY: "MONTHLY";
};
export type Granularity = (typeof Granularity)[keyof typeof Granularity];
export declare const GroupDefinitionType: {
  readonly COST_CATEGORY: "COST_CATEGORY";
  readonly DIMENSION: "DIMENSION";
  readonly TAG: "TAG";
};
export type GroupDefinitionType =
  (typeof GroupDefinitionType)[keyof typeof GroupDefinitionType];
export interface GroupDefinition {
  Type?: GroupDefinitionType | string;
  Key?: string;
}
export interface DateInterval {
  Start: string | undefined;
  End: string | undefined;
}
export interface DimensionValuesWithAttributes {
  Value?: string;
  Attributes?: Record<string, string>;
}
export interface MetricValue {
  Amount?: string;
  Unit?: string;
}
export interface Group {
  Keys?: string[];
  Metrics?: Record<string, MetricValue>;
}
export interface ResultByTime {
  TimePeriod?: DateInterval;
  Total?: Record<string, MetricValue>;
  Groups?: Group[];
  Estimated?: boolean;
}
export interface GetCostAndUsageResponse {
  NextPageToken?: string;
  GroupDefinitions?: GroupDefinition[];
  ResultsByTime?: ResultByTime[];
  DimensionValueAttributes?: DimensionValuesWithAttributes[];
}
export declare class RequestChangedException extends __BaseException {
  readonly name: "RequestChangedException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<RequestChangedException, __BaseException>
  );
}
export interface GetCostAndUsageWithResourcesResponse {
  NextPageToken?: string;
  GroupDefinitions?: GroupDefinition[];
  ResultsByTime?: ResultByTime[];
  DimensionValueAttributes?: DimensionValuesWithAttributes[];
}
export declare const SortOrder: {
  readonly ASCENDING: "ASCENDING";
  readonly DESCENDING: "DESCENDING";
};
export type SortOrder = (typeof SortOrder)[keyof typeof SortOrder];
export interface SortDefinition {
  Key: string | undefined;
  SortOrder?: SortOrder | string;
}
export interface GetCostCategoriesResponse {
  NextPageToken?: string;
  CostCategoryNames?: string[];
  CostCategoryValues?: string[];
  ReturnSize: number | undefined;
  TotalSize: number | undefined;
}
export declare const Metric: {
  readonly AMORTIZED_COST: "AMORTIZED_COST";
  readonly BLENDED_COST: "BLENDED_COST";
  readonly NET_AMORTIZED_COST: "NET_AMORTIZED_COST";
  readonly NET_UNBLENDED_COST: "NET_UNBLENDED_COST";
  readonly NORMALIZED_USAGE_AMOUNT: "NORMALIZED_USAGE_AMOUNT";
  readonly UNBLENDED_COST: "UNBLENDED_COST";
  readonly USAGE_QUANTITY: "USAGE_QUANTITY";
};
export type Metric = (typeof Metric)[keyof typeof Metric];
export interface ForecastResult {
  TimePeriod?: DateInterval;
  MeanValue?: string;
  PredictionIntervalLowerBound?: string;
  PredictionIntervalUpperBound?: string;
}
export interface GetCostForecastResponse {
  Total?: MetricValue;
  ForecastResultsByTime?: ForecastResult[];
}
export declare const Context: {
  readonly COST_AND_USAGE: "COST_AND_USAGE";
  readonly RESERVATIONS: "RESERVATIONS";
  readonly SAVINGS_PLANS: "SAVINGS_PLANS";
};
export type Context = (typeof Context)[keyof typeof Context];
export interface GetDimensionValuesResponse {
  DimensionValues: DimensionValuesWithAttributes[] | undefined;
  ReturnSize: number | undefined;
  TotalSize: number | undefined;
  NextPageToken?: string;
}
export interface CoverageCost {
  OnDemandCost?: string;
}
export interface CoverageHours {
  OnDemandHours?: string;
  ReservedHours?: string;
  TotalRunningHours?: string;
  CoverageHoursPercentage?: string;
}
export interface CoverageNormalizedUnits {
  OnDemandNormalizedUnits?: string;
  ReservedNormalizedUnits?: string;
  TotalRunningNormalizedUnits?: string;
  CoverageNormalizedUnitsPercentage?: string;
}
export interface Coverage {
  CoverageHours?: CoverageHours;
  CoverageNormalizedUnits?: CoverageNormalizedUnits;
  CoverageCost?: CoverageCost;
}
export interface ReservationCoverageGroup {
  Attributes?: Record<string, string>;
  Coverage?: Coverage;
}
export interface CoverageByTime {
  TimePeriod?: DateInterval;
  Groups?: ReservationCoverageGroup[];
  Total?: Coverage;
}
export interface GetReservationCoverageResponse {
  CoveragesByTime: CoverageByTime[] | undefined;
  Total?: Coverage;
  NextPageToken?: string;
}
export declare const LookbackPeriodInDays: {
  readonly SEVEN_DAYS: "SEVEN_DAYS";
  readonly SIXTY_DAYS: "SIXTY_DAYS";
  readonly THIRTY_DAYS: "THIRTY_DAYS";
};
export type LookbackPeriodInDays =
  (typeof LookbackPeriodInDays)[keyof typeof LookbackPeriodInDays];
export declare const PaymentOption: {
  readonly ALL_UPFRONT: "ALL_UPFRONT";
  readonly HEAVY_UTILIZATION: "HEAVY_UTILIZATION";
  readonly LIGHT_UTILIZATION: "LIGHT_UTILIZATION";
  readonly MEDIUM_UTILIZATION: "MEDIUM_UTILIZATION";
  readonly NO_UPFRONT: "NO_UPFRONT";
  readonly PARTIAL_UPFRONT: "PARTIAL_UPFRONT";
};
export type PaymentOption = (typeof PaymentOption)[keyof typeof PaymentOption];
export declare const OfferingClass: {
  readonly CONVERTIBLE: "CONVERTIBLE";
  readonly STANDARD: "STANDARD";
};
export type OfferingClass = (typeof OfferingClass)[keyof typeof OfferingClass];
export interface EC2Specification {
  OfferingClass?: OfferingClass | string;
}
export interface ServiceSpecification {
  EC2Specification?: EC2Specification;
}
export declare const TermInYears: {
  readonly ONE_YEAR: "ONE_YEAR";
  readonly THREE_YEARS: "THREE_YEARS";
};
export type TermInYears = (typeof TermInYears)[keyof typeof TermInYears];
export interface ReservationPurchaseRecommendationMetadata {
  RecommendationId?: string;
  GenerationTimestamp?: string;
}
export interface EC2InstanceDetails {
  Family?: string;
  InstanceType?: string;
  Region?: string;
  AvailabilityZone?: string;
  Platform?: string;
  Tenancy?: string;
  CurrentGeneration?: boolean;
  SizeFlexEligible?: boolean;
}
export interface ElastiCacheInstanceDetails {
  Family?: string;
  NodeType?: string;
  Region?: string;
  ProductDescription?: string;
  CurrentGeneration?: boolean;
  SizeFlexEligible?: boolean;
}
export interface ESInstanceDetails {
  InstanceClass?: string;
  InstanceSize?: string;
  Region?: string;
  CurrentGeneration?: boolean;
  SizeFlexEligible?: boolean;
}
export interface RDSInstanceDetails {
  Family?: string;
  InstanceType?: string;
  Region?: string;
  DatabaseEngine?: string;
  DatabaseEdition?: string;
  DeploymentOption?: string;
  LicenseModel?: string;
  CurrentGeneration?: boolean;
  SizeFlexEligible?: boolean;
}
export interface RedshiftInstanceDetails {
  Family?: string;
  NodeType?: string;
  Region?: string;
  CurrentGeneration?: boolean;
  SizeFlexEligible?: boolean;
}
export interface InstanceDetails {
  EC2InstanceDetails?: EC2InstanceDetails;
  RDSInstanceDetails?: RDSInstanceDetails;
  RedshiftInstanceDetails?: RedshiftInstanceDetails;
  ElastiCacheInstanceDetails?: ElastiCacheInstanceDetails;
  ESInstanceDetails?: ESInstanceDetails;
}
export interface ReservationPurchaseRecommendationDetail {
  AccountId?: string;
  InstanceDetails?: InstanceDetails;
  RecommendedNumberOfInstancesToPurchase?: string;
  RecommendedNormalizedUnitsToPurchase?: string;
  MinimumNumberOfInstancesUsedPerHour?: string;
  MinimumNormalizedUnitsUsedPerHour?: string;
  MaximumNumberOfInstancesUsedPerHour?: string;
  MaximumNormalizedUnitsUsedPerHour?: string;
  AverageNumberOfInstancesUsedPerHour?: string;
  AverageNormalizedUnitsUsedPerHour?: string;
  AverageUtilization?: string;
  EstimatedBreakEvenInMonths?: string;
  CurrencyCode?: string;
  EstimatedMonthlySavingsAmount?: string;
  EstimatedMonthlySavingsPercentage?: string;
  EstimatedMonthlyOnDemandCost?: string;
  EstimatedReservationCostForLookbackPeriod?: string;
  UpfrontCost?: string;
  RecurringStandardMonthlyCost?: string;
}
export interface ReservationPurchaseRecommendationSummary {
  TotalEstimatedMonthlySavingsAmount?: string;
  TotalEstimatedMonthlySavingsPercentage?: string;
  CurrencyCode?: string;
}
export interface ReservationPurchaseRecommendation {
  AccountScope?: AccountScope | string;
  LookbackPeriodInDays?: LookbackPeriodInDays | string;
  TermInYears?: TermInYears | string;
  PaymentOption?: PaymentOption | string;
  ServiceSpecification?: ServiceSpecification;
  RecommendationDetails?: ReservationPurchaseRecommendationDetail[];
  RecommendationSummary?: ReservationPurchaseRecommendationSummary;
}
export interface GetReservationPurchaseRecommendationResponse {
  Metadata?: ReservationPurchaseRecommendationMetadata;
  Recommendations?: ReservationPurchaseRecommendation[];
  NextPageToken?: string;
}
export interface ReservationAggregates {
  UtilizationPercentage?: string;
  UtilizationPercentageInUnits?: string;
  PurchasedHours?: string;
  PurchasedUnits?: string;
  TotalActualHours?: string;
  TotalActualUnits?: string;
  UnusedHours?: string;
  UnusedUnits?: string;
  OnDemandCostOfRIHoursUsed?: string;
  NetRISavings?: string;
  TotalPotentialRISavings?: string;
  AmortizedUpfrontFee?: string;
  AmortizedRecurringFee?: string;
  TotalAmortizedFee?: string;
  RICostForUnusedHours?: string;
  RealizedSavings?: string;
  UnrealizedSavings?: string;
}
export interface ReservationUtilizationGroup {
  Key?: string;
  Value?: string;
  Attributes?: Record<string, string>;
  Utilization?: ReservationAggregates;
}
export interface UtilizationByTime {
  TimePeriod?: DateInterval;
  Groups?: ReservationUtilizationGroup[];
  Total?: ReservationAggregates;
}
export interface GetReservationUtilizationResponse {
  UtilizationsByTime: UtilizationByTime[] | undefined;
  Total?: ReservationAggregates;
  NextPageToken?: string;
}
export declare const RecommendationTarget: {
  readonly CROSS_INSTANCE_FAMILY: "CROSS_INSTANCE_FAMILY";
  readonly SAME_INSTANCE_FAMILY: "SAME_INSTANCE_FAMILY";
};
export type RecommendationTarget =
  (typeof RecommendationTarget)[keyof typeof RecommendationTarget];
export interface RightsizingRecommendationConfiguration {
  RecommendationTarget: RecommendationTarget | string | undefined;
  BenefitsConsidered: boolean | undefined;
}
export interface RightsizingRecommendationMetadata {
  RecommendationId?: string;
  GenerationTimestamp?: string;
  LookbackPeriodInDays?: LookbackPeriodInDays | string;
  AdditionalMetadata?: string;
}
export interface EC2ResourceDetails {
  HourlyOnDemandRate?: string;
  InstanceType?: string;
  Platform?: string;
  Region?: string;
  Sku?: string;
  Memory?: string;
  NetworkPerformance?: string;
  Storage?: string;
  Vcpu?: string;
}
export interface ResourceDetails {
  EC2ResourceDetails?: EC2ResourceDetails;
}
export interface DiskResourceUtilization {
  DiskReadOpsPerSecond?: string;
  DiskWriteOpsPerSecond?: string;
  DiskReadBytesPerSecond?: string;
  DiskWriteBytesPerSecond?: string;
}
export interface EBSResourceUtilization {
  EbsReadOpsPerSecond?: string;
  EbsWriteOpsPerSecond?: string;
  EbsReadBytesPerSecond?: string;
  EbsWriteBytesPerSecond?: string;
}
export interface NetworkResourceUtilization {
  NetworkInBytesPerSecond?: string;
  NetworkOutBytesPerSecond?: string;
  NetworkPacketsInPerSecond?: string;
  NetworkPacketsOutPerSecond?: string;
}
export interface EC2ResourceUtilization {
  MaxCpuUtilizationPercentage?: string;
  MaxMemoryUtilizationPercentage?: string;
  MaxStorageUtilizationPercentage?: string;
  EBSResourceUtilization?: EBSResourceUtilization;
  DiskResourceUtilization?: DiskResourceUtilization;
  NetworkResourceUtilization?: NetworkResourceUtilization;
}
export interface ResourceUtilization {
  EC2ResourceUtilization?: EC2ResourceUtilization;
}
export interface CurrentInstance {
  ResourceId?: string;
  InstanceName?: string;
  Tags?: TagValues[];
  ResourceDetails?: ResourceDetails;
  ResourceUtilization?: ResourceUtilization;
  ReservationCoveredHoursInLookbackPeriod?: string;
  SavingsPlansCoveredHoursInLookbackPeriod?: string;
  OnDemandHoursInLookbackPeriod?: string;
  TotalRunningHoursInLookbackPeriod?: string;
  MonthlyCost?: string;
  CurrencyCode?: string;
}
export declare const FindingReasonCode: {
  readonly CPU_OVER_PROVISIONED: "CPU_OVER_PROVISIONED";
  readonly CPU_UNDER_PROVISIONED: "CPU_UNDER_PROVISIONED";
  readonly DISK_IOPS_OVER_PROVISIONED: "DISK_IOPS_OVER_PROVISIONED";
  readonly DISK_IOPS_UNDER_PROVISIONED: "DISK_IOPS_UNDER_PROVISIONED";
  readonly DISK_THROUGHPUT_OVER_PROVISIONED: "DISK_THROUGHPUT_OVER_PROVISIONED";
  readonly DISK_THROUGHPUT_UNDER_PROVISIONED: "DISK_THROUGHPUT_UNDER_PROVISIONED";
  readonly EBS_IOPS_OVER_PROVISIONED: "EBS_IOPS_OVER_PROVISIONED";
  readonly EBS_IOPS_UNDER_PROVISIONED: "EBS_IOPS_UNDER_PROVISIONED";
  readonly EBS_THROUGHPUT_OVER_PROVISIONED: "EBS_THROUGHPUT_OVER_PROVISIONED";
  readonly EBS_THROUGHPUT_UNDER_PROVISIONED: "EBS_THROUGHPUT_UNDER_PROVISIONED";
  readonly MEMORY_OVER_PROVISIONED: "MEMORY_OVER_PROVISIONED";
  readonly MEMORY_UNDER_PROVISIONED: "MEMORY_UNDER_PROVISIONED";
  readonly NETWORK_BANDWIDTH_OVER_PROVISIONED: "NETWORK_BANDWIDTH_OVER_PROVISIONED";
  readonly NETWORK_BANDWIDTH_UNDER_PROVISIONED: "NETWORK_BANDWIDTH_UNDER_PROVISIONED";
  readonly NETWORK_PPS_OVER_PROVISIONED: "NETWORK_PPS_OVER_PROVISIONED";
  readonly NETWORK_PPS_UNDER_PROVISIONED: "NETWORK_PPS_UNDER_PROVISIONED";
};
export type FindingReasonCode =
  (typeof FindingReasonCode)[keyof typeof FindingReasonCode];
export declare const PlatformDifference: {
  readonly HYPERVISOR: "HYPERVISOR";
  readonly INSTANCE_STORE_AVAILABILITY: "INSTANCE_STORE_AVAILABILITY";
  readonly NETWORK_INTERFACE: "NETWORK_INTERFACE";
  readonly STORAGE_INTERFACE: "STORAGE_INTERFACE";
  readonly VIRTUALIZATION_TYPE: "VIRTUALIZATION_TYPE";
};
export type PlatformDifference =
  (typeof PlatformDifference)[keyof typeof PlatformDifference];
export interface TargetInstance {
  EstimatedMonthlyCost?: string;
  EstimatedMonthlySavings?: string;
  CurrencyCode?: string;
  DefaultTargetInstance?: boolean;
  ResourceDetails?: ResourceDetails;
  ExpectedResourceUtilization?: ResourceUtilization;
  PlatformDifferences?: (PlatformDifference | string)[];
}
export interface ModifyRecommendationDetail {
  TargetInstances?: TargetInstance[];
}
export declare const RightsizingType: {
  readonly MODIFY: "MODIFY";
  readonly TERMINATE: "TERMINATE";
};
export type RightsizingType =
  (typeof RightsizingType)[keyof typeof RightsizingType];
export interface TerminateRecommendationDetail {
  EstimatedMonthlySavings?: string;
  CurrencyCode?: string;
}
export interface RightsizingRecommendation {
  AccountId?: string;
  CurrentInstance?: CurrentInstance;
  RightsizingType?: RightsizingType | string;
  ModifyRecommendationDetail?: ModifyRecommendationDetail;
  TerminateRecommendationDetail?: TerminateRecommendationDetail;
  FindingReasonCodes?: (FindingReasonCode | string)[];
}
export interface RightsizingRecommendationSummary {
  TotalRecommendationCount?: string;
  EstimatedTotalMonthlySavingsAmount?: string;
  SavingsCurrencyCode?: string;
  SavingsPercentage?: string;
}
export interface GetRightsizingRecommendationResponse {
  Metadata?: RightsizingRecommendationMetadata;
  Summary?: RightsizingRecommendationSummary;
  RightsizingRecommendations?: RightsizingRecommendation[];
  NextPageToken?: string;
  Configuration?: RightsizingRecommendationConfiguration;
}
export interface SavingsPlansCoverageData {
  SpendCoveredBySavingsPlans?: string;
  OnDemandCost?: string;
  TotalCost?: string;
  CoveragePercentage?: string;
}
export interface SavingsPlansCoverage {
  Attributes?: Record<string, string>;
  Coverage?: SavingsPlansCoverageData;
  TimePeriod?: DateInterval;
}
export interface GetSavingsPlansCoverageResponse {
  SavingsPlansCoverages: SavingsPlansCoverage[] | undefined;
  NextToken?: string;
}
export declare const SupportedSavingsPlansType: {
  readonly COMPUTE_SP: "COMPUTE_SP";
  readonly EC2_INSTANCE_SP: "EC2_INSTANCE_SP";
  readonly SAGEMAKER_SP: "SAGEMAKER_SP";
};
export type SupportedSavingsPlansType =
  (typeof SupportedSavingsPlansType)[keyof typeof SupportedSavingsPlansType];
export interface SavingsPlansPurchaseRecommendationMetadata {
  RecommendationId?: string;
  GenerationTimestamp?: string;
  AdditionalMetadata?: string;
}
export interface SavingsPlansDetails {
  Region?: string;
  InstanceFamily?: string;
  OfferingId?: string;
}
export interface SavingsPlansPurchaseRecommendationDetail {
  SavingsPlansDetails?: SavingsPlansDetails;
  AccountId?: string;
  UpfrontCost?: string;
  EstimatedROI?: string;
  CurrencyCode?: string;
  EstimatedSPCost?: string;
  EstimatedOnDemandCost?: string;
  EstimatedOnDemandCostWithCurrentCommitment?: string;
  EstimatedSavingsAmount?: string;
  EstimatedSavingsPercentage?: string;
  HourlyCommitmentToPurchase?: string;
  EstimatedAverageUtilization?: string;
  EstimatedMonthlySavingsAmount?: string;
  CurrentMinimumHourlyOnDemandSpend?: string;
  CurrentMaximumHourlyOnDemandSpend?: string;
  CurrentAverageHourlyOnDemandSpend?: string;
}
export interface SavingsPlansPurchaseRecommendationSummary {
  EstimatedROI?: string;
  CurrencyCode?: string;
  EstimatedTotalCost?: string;
  CurrentOnDemandSpend?: string;
  EstimatedSavingsAmount?: string;
  TotalRecommendationCount?: string;
  DailyCommitmentToPurchase?: string;
  HourlyCommitmentToPurchase?: string;
  EstimatedSavingsPercentage?: string;
  EstimatedMonthlySavingsAmount?: string;
  EstimatedOnDemandCostWithCurrentCommitment?: string;
}
export interface SavingsPlansPurchaseRecommendation {
  AccountScope?: AccountScope | string;
  SavingsPlansType?: SupportedSavingsPlansType | string;
  TermInYears?: TermInYears | string;
  PaymentOption?: PaymentOption | string;
  LookbackPeriodInDays?: LookbackPeriodInDays | string;
  SavingsPlansPurchaseRecommendationDetails?: SavingsPlansPurchaseRecommendationDetail[];
  SavingsPlansPurchaseRecommendationSummary?: SavingsPlansPurchaseRecommendationSummary;
}
export interface GetSavingsPlansPurchaseRecommendationResponse {
  Metadata?: SavingsPlansPurchaseRecommendationMetadata;
  SavingsPlansPurchaseRecommendation?: SavingsPlansPurchaseRecommendation;
  NextPageToken?: string;
}
export interface SavingsPlansAmortizedCommitment {
  AmortizedRecurringCommitment?: string;
  AmortizedUpfrontCommitment?: string;
  TotalAmortizedCommitment?: string;
}
export interface SavingsPlansSavings {
  NetSavings?: string;
  OnDemandCostEquivalent?: string;
}
export interface SavingsPlansUtilization {
  TotalCommitment?: string;
  UsedCommitment?: string;
  UnusedCommitment?: string;
  UtilizationPercentage?: string;
}
export interface SavingsPlansUtilizationByTime {
  TimePeriod: DateInterval | undefined;
  Utilization: SavingsPlansUtilization | undefined;
  Savings?: SavingsPlansSavings;
  AmortizedCommitment?: SavingsPlansAmortizedCommitment;
}
export interface SavingsPlansUtilizationAggregates {
  Utilization: SavingsPlansUtilization | undefined;
  Savings?: SavingsPlansSavings;
  AmortizedCommitment?: SavingsPlansAmortizedCommitment;
}
export interface GetSavingsPlansUtilizationResponse {
  SavingsPlansUtilizationsByTime?: SavingsPlansUtilizationByTime[];
  Total: SavingsPlansUtilizationAggregates | undefined;
}
export declare const SavingsPlansDataType: {
  readonly AMORTIZED_COMMITMENT: "AMORTIZED_COMMITMENT";
  readonly ATTRIBUTES: "ATTRIBUTES";
  readonly SAVINGS: "SAVINGS";
  readonly UTILIZATION: "UTILIZATION";
};
export type SavingsPlansDataType =
  (typeof SavingsPlansDataType)[keyof typeof SavingsPlansDataType];
export interface SavingsPlansUtilizationDetail {
  SavingsPlanArn?: string;
  Attributes?: Record<string, string>;
  Utilization?: SavingsPlansUtilization;
  Savings?: SavingsPlansSavings;
  AmortizedCommitment?: SavingsPlansAmortizedCommitment;
}
export interface GetSavingsPlansUtilizationDetailsResponse {
  SavingsPlansUtilizationDetails: SavingsPlansUtilizationDetail[] | undefined;
  Total?: SavingsPlansUtilizationAggregates;
  TimePeriod: DateInterval | undefined;
  NextToken?: string;
}
export interface GetTagsResponse {
  NextPageToken?: string;
  Tags: string[] | undefined;
  ReturnSize: number | undefined;
  TotalSize: number | undefined;
}
export interface GetUsageForecastResponse {
  Total?: MetricValue;
  ForecastResultsByTime?: ForecastResult[];
}
export declare class UnresolvableUsageUnitException extends __BaseException {
  readonly name: "UnresolvableUsageUnitException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<UnresolvableUsageUnitException, __BaseException>
  );
}
export declare const CostAllocationTagStatus: {
  readonly ACTIVE: "Active";
  readonly INACTIVE: "Inactive";
};
export type CostAllocationTagStatus =
  (typeof CostAllocationTagStatus)[keyof typeof CostAllocationTagStatus];
export declare const CostAllocationTagType: {
  readonly AWS_GENERATED: "AWSGenerated";
  readonly USER_DEFINED: "UserDefined";
};
export type CostAllocationTagType =
  (typeof CostAllocationTagType)[keyof typeof CostAllocationTagType];
export interface ListCostAllocationTagsRequest {
  Status?: CostAllocationTagStatus | string;
  TagKeys?: string[];
  Type?: CostAllocationTagType | string;
  NextToken?: string;
  MaxResults?: number;
}
export interface CostAllocationTag {
  TagKey: string | undefined;
  Type: CostAllocationTagType | string | undefined;
  Status: CostAllocationTagStatus | string | undefined;
}
export interface ListCostAllocationTagsResponse {
  CostAllocationTags?: CostAllocationTag[];
  NextToken?: string;
}
export interface ListCostCategoryDefinitionsRequest {
  EffectiveOn?: string;
  NextToken?: string;
  MaxResults?: number;
}
export interface CostCategoryReference {
  CostCategoryArn?: string;
  Name?: string;
  EffectiveStart?: string;
  EffectiveEnd?: string;
  NumberOfRules?: number;
  ProcessingStatus?: CostCategoryProcessingStatus[];
  Values?: string[];
  DefaultValue?: string;
}
export interface ListCostCategoryDefinitionsResponse {
  CostCategoryReferences?: CostCategoryReference[];
  NextToken?: string;
}
export declare const GenerationStatus: {
  readonly FAILED: "FAILED";
  readonly PROCESSING: "PROCESSING";
  readonly SUCCEEDED: "SUCCEEDED";
};
export type GenerationStatus =
  (typeof GenerationStatus)[keyof typeof GenerationStatus];
export interface ListSavingsPlansPurchaseRecommendationGenerationRequest {
  GenerationStatus?: GenerationStatus | string;
  RecommendationIds?: string[];
  PageSize?: number;
  NextPageToken?: string;
}
export interface GenerationSummary {
  RecommendationId?: string;
  GenerationStatus?: GenerationStatus | string;
  GenerationStartedTime?: string;
  GenerationCompletionTime?: string;
  EstimatedCompletionTime?: string;
}
export interface ListSavingsPlansPurchaseRecommendationGenerationResponse {
  GenerationSummaryList?: GenerationSummary[];
  NextPageToken?: string;
}
export interface ListTagsForResourceRequest {
  ResourceArn: string | undefined;
}
export interface ListTagsForResourceResponse {
  ResourceTags?: ResourceTag[];
}
export interface ProvideAnomalyFeedbackRequest {
  AnomalyId: string | undefined;
  Feedback: AnomalyFeedbackType | string | undefined;
}
export interface ProvideAnomalyFeedbackResponse {
  AnomalyId: string | undefined;
}
export declare class GenerationExistsException extends __BaseException {
  readonly name: "GenerationExistsException";
  readonly $fault: "client";
  Message?: string;
  constructor(
    opts: __ExceptionOptionType<GenerationExistsException, __BaseException>
  );
}
export interface StartSavingsPlansPurchaseRecommendationGenerationRequest {}
export interface StartSavingsPlansPurchaseRecommendationGenerationResponse {
  RecommendationId?: string;
  GenerationStartedTime?: string;
  EstimatedCompletionTime?: string;
}
export interface TagResourceRequest {
  ResourceArn: string | undefined;
  ResourceTags: ResourceTag[] | undefined;
}
export interface TagResourceResponse {}
export declare class TooManyTagsException extends __BaseException {
  readonly name: "TooManyTagsException";
  readonly $fault: "client";
  Message?: string;
  ResourceName?: string;
  constructor(
    opts: __ExceptionOptionType<TooManyTagsException, __BaseException>
  );
}
export interface UntagResourceRequest {
  ResourceArn: string | undefined;
  ResourceTagKeys: string[] | undefined;
}
export interface UntagResourceResponse {}
export interface UpdateAnomalyMonitorRequest {
  MonitorArn: string | undefined;
  MonitorName?: string;
}
export interface UpdateAnomalyMonitorResponse {
  MonitorArn: string | undefined;
}
export interface UpdateAnomalySubscriptionResponse {
  SubscriptionArn: string | undefined;
}
export interface CostAllocationTagStatusEntry {
  TagKey: string | undefined;
  Status: CostAllocationTagStatus | string | undefined;
}
export interface UpdateCostAllocationTagsStatusRequest {
  CostAllocationTagsStatus: CostAllocationTagStatusEntry[] | undefined;
}
export interface UpdateCostAllocationTagsStatusError {
  TagKey?: string;
  Code?: string;
  Message?: string;
}
export interface UpdateCostAllocationTagsStatusResponse {
  Errors?: UpdateCostAllocationTagsStatusError[];
}
export interface UpdateCostCategoryDefinitionResponse {
  CostCategoryArn?: string;
  EffectiveStart?: string;
}
export interface Expression {
  Or?: Expression[];
  And?: Expression[];
  Not?: Expression;
  Dimensions?: DimensionValues;
  Tags?: TagValues;
  CostCategories?: CostCategoryValues;
}
export interface AnomalyMonitor {
  MonitorArn?: string;
  MonitorName: string | undefined;
  CreationDate?: string;
  LastUpdatedDate?: string;
  LastEvaluatedDate?: string;
  MonitorType: MonitorType | string | undefined;
  MonitorDimension?: MonitorDimension | string;
  MonitorSpecification?: Expression;
  DimensionalValueCount?: number;
}
export interface AnomalySubscription {
  SubscriptionArn?: string;
  AccountId?: string;
  MonitorArnList: string[] | undefined;
  Subscribers: Subscriber[] | undefined;
  Threshold?: number;
  Frequency: AnomalySubscriptionFrequency | string | undefined;
  SubscriptionName: string | undefined;
  ThresholdExpression?: Expression;
}
export interface CostCategoryRule {
  Value?: string;
  Rule?: Expression;
  InheritedValue?: CostCategoryInheritedValueDimension;
  Type?: CostCategoryRuleType | string;
}
export interface GetCostAndUsageRequest {
  TimePeriod: DateInterval | undefined;
  Granularity: Granularity | string | undefined;
  Filter?: Expression;
  Metrics: string[] | undefined;
  GroupBy?: GroupDefinition[];
  NextPageToken?: string;
}
export interface GetCostAndUsageWithResourcesRequest {
  TimePeriod: DateInterval | undefined;
  Granularity: Granularity | string | undefined;
  Filter: Expression | undefined;
  Metrics?: string[];
  GroupBy?: GroupDefinition[];
  NextPageToken?: string;
}
export interface GetCostCategoriesRequest {
  SearchString?: string;
  TimePeriod: DateInterval | undefined;
  CostCategoryName?: string;
  Filter?: Expression;
  SortBy?: SortDefinition[];
  MaxResults?: number;
  NextPageToken?: string;
}
export interface GetCostForecastRequest {
  TimePeriod: DateInterval | undefined;
  Metric: Metric | string | undefined;
  Granularity: Granularity | string | undefined;
  Filter?: Expression;
  PredictionIntervalLevel?: number;
}
export interface GetDimensionValuesRequest {
  SearchString?: string;
  TimePeriod: DateInterval | undefined;
  Dimension: Dimension | string | undefined;
  Context?: Context | string;
  Filter?: Expression;
  SortBy?: SortDefinition[];
  MaxResults?: number;
  NextPageToken?: string;
}
export interface GetReservationCoverageRequest {
  TimePeriod: DateInterval | undefined;
  GroupBy?: GroupDefinition[];
  Granularity?: Granularity | string;
  Filter?: Expression;
  Metrics?: string[];
  NextPageToken?: string;
  SortBy?: SortDefinition;
  MaxResults?: number;
}
export interface GetReservationPurchaseRecommendationRequest {
  AccountId?: string;
  Service: string | undefined;
  Filter?: Expression;
  AccountScope?: AccountScope | string;
  LookbackPeriodInDays?: LookbackPeriodInDays | string;
  TermInYears?: TermInYears | string;
  PaymentOption?: PaymentOption | string;
  ServiceSpecification?: ServiceSpecification;
  PageSize?: number;
  NextPageToken?: string;
}
export interface GetReservationUtilizationRequest {
  TimePeriod: DateInterval | undefined;
  GroupBy?: GroupDefinition[];
  Granularity?: Granularity | string;
  Filter?: Expression;
  SortBy?: SortDefinition;
  NextPageToken?: string;
  MaxResults?: number;
}
export interface GetRightsizingRecommendationRequest {
  Filter?: Expression;
  Configuration?: RightsizingRecommendationConfiguration;
  Service: string | undefined;
  PageSize?: number;
  NextPageToken?: string;
}
export interface GetSavingsPlansCoverageRequest {
  TimePeriod: DateInterval | undefined;
  GroupBy?: GroupDefinition[];
  Granularity?: Granularity | string;
  Filter?: Expression;
  Metrics?: string[];
  NextToken?: string;
  MaxResults?: number;
  SortBy?: SortDefinition;
}
export interface GetSavingsPlansPurchaseRecommendationRequest {
  SavingsPlansType: SupportedSavingsPlansType | string | undefined;
  TermInYears: TermInYears | string | undefined;
  PaymentOption: PaymentOption | string | undefined;
  AccountScope?: AccountScope | string;
  NextPageToken?: string;
  PageSize?: number;
  LookbackPeriodInDays: LookbackPeriodInDays | string | undefined;
  Filter?: Expression;
}
export interface GetSavingsPlansUtilizationDetailsRequest {
  TimePeriod: DateInterval | undefined;
  Filter?: Expression;
  DataType?: (SavingsPlansDataType | string)[];
  NextToken?: string;
  MaxResults?: number;
  SortBy?: SortDefinition;
}
export interface GetSavingsPlansUtilizationRequest {
  TimePeriod: DateInterval | undefined;
  Granularity?: Granularity | string;
  Filter?: Expression;
  SortBy?: SortDefinition;
}
export interface GetTagsRequest {
  SearchString?: string;
  TimePeriod: DateInterval | undefined;
  TagKey?: string;
  Filter?: Expression;
  SortBy?: SortDefinition[];
  MaxResults?: number;
  NextPageToken?: string;
}
export interface GetUsageForecastRequest {
  TimePeriod: DateInterval | undefined;
  Metric: Metric | string | undefined;
  Granularity: Granularity | string | undefined;
  Filter?: Expression;
  PredictionIntervalLevel?: number;
}
export interface UpdateAnomalySubscriptionRequest {
  SubscriptionArn: string | undefined;
  Threshold?: number;
  Frequency?: AnomalySubscriptionFrequency | string;
  MonitorArnList?: string[];
  Subscribers?: Subscriber[];
  SubscriptionName?: string;
  ThresholdExpression?: Expression;
}
export interface CreateAnomalyMonitorRequest {
  AnomalyMonitor: AnomalyMonitor | undefined;
  ResourceTags?: ResourceTag[];
}
export interface CreateAnomalySubscriptionRequest {
  AnomalySubscription: AnomalySubscription | undefined;
  ResourceTags?: ResourceTag[];
}
export interface CostCategory {
  CostCategoryArn: string | undefined;
  EffectiveStart: string | undefined;
  EffectiveEnd?: string;
  Name: string | undefined;
  RuleVersion: CostCategoryRuleVersion | string | undefined;
  Rules: CostCategoryRule[] | undefined;
  SplitChargeRules?: CostCategorySplitChargeRule[];
  ProcessingStatus?: CostCategoryProcessingStatus[];
  DefaultValue?: string;
}
export interface CreateCostCategoryDefinitionRequest {
  Name: string | undefined;
  EffectiveStart?: string;
  RuleVersion: CostCategoryRuleVersion | string | undefined;
  Rules: CostCategoryRule[] | undefined;
  DefaultValue?: string;
  SplitChargeRules?: CostCategorySplitChargeRule[];
  ResourceTags?: ResourceTag[];
}
export interface GetAnomalyMonitorsResponse {
  AnomalyMonitors: AnomalyMonitor[] | undefined;
  NextPageToken?: string;
}
export interface GetAnomalySubscriptionsResponse {
  AnomalySubscriptions: AnomalySubscription[] | undefined;
  NextPageToken?: string;
}
export interface UpdateCostCategoryDefinitionRequest {
  CostCategoryArn: string | undefined;
  EffectiveStart?: string;
  RuleVersion: CostCategoryRuleVersion | string | undefined;
  Rules: CostCategoryRule[] | undefined;
  DefaultValue?: string;
  SplitChargeRules?: CostCategorySplitChargeRule[];
}
export interface DescribeCostCategoryDefinitionResponse {
  CostCategory?: CostCategory;
}
